summaryrefslogtreecommitdiffstats
path: root/kate
diff options
context:
space:
mode:
Diffstat (limited to 'kate')
-rw-r--r--kate/COPYING.LIB12
-rw-r--r--kate/ChangeLog6
-rw-r--r--kate/README2
-rw-r--r--kate/app/kateapp.cpp4
-rw-r--r--kate/app/kateappIface.cpp2
-rw-r--r--kate/app/kateconfigdialog.cpp2
-rw-r--r--kate/app/kateconsole.cpp6
-rw-r--r--kate/app/katedocmanager.cpp8
-rw-r--r--kate/app/katedocmanager.h2
-rw-r--r--kate/app/kateexternaltools.cpp26
-rw-r--r--kate/app/kateexternaltools.h2
-rw-r--r--kate/app/katefilelist.cpp18
-rw-r--r--kate/app/katefilelist.h2
-rw-r--r--kate/app/katefileselector.cpp18
-rw-r--r--kate/app/katefileselector.h2
-rw-r--r--kate/app/kategrepdialog.cpp58
-rw-r--r--kate/app/katemailfilesdialog.cpp6
-rw-r--r--kate/app/katemain.cpp2
-rw-r--r--kate/app/katemainwindow.cpp12
-rw-r--r--kate/app/katemainwindow.h2
-rw-r--r--kate/app/katemdi.cpp14
-rw-r--r--kate/app/katemdi.h2
-rw-r--r--kate/app/katemwmodonhddialog.cpp4
-rw-r--r--kate/app/katemwmodonhddialog.h2
-rw-r--r--kate/app/katesession.cpp2
-rw-r--r--kate/app/katetabwidget.cpp6
-rw-r--r--kate/app/kateviewmanager.cpp2
-rw-r--r--kate/app/kateviewspace.cpp24
-rw-r--r--kate/app/kateviewspace.h4
-rw-r--r--kate/app/kateviewspacecontainer.cpp38
-rw-r--r--kate/app/kwritemain.cpp12
-rw-r--r--kate/app/kwritemain.h4
-rw-r--r--kate/data/tips4
-rw-r--r--kate/interfaces/mainwindow.cpp2
-rw-r--r--kate/interfaces/mainwindow.h2
-rw-r--r--kate/utils/dockviewbase.cpp2
36 files changed, 158 insertions, 158 deletions
diff --git a/kate/COPYING.LIB b/kate/COPYING.LIB
index 61359d115..789c31eee 100644
--- a/kate/COPYING.LIB
+++ b/kate/COPYING.LIB
@@ -94,7 +94,7 @@ will lead to faster development of free libraries.
The precise terms and conditions for copying, distribution and
modification follow. Pay close attention to the difference between a
"work based on the library" and a "work that uses the library". The
-former tqcontains code derived from the library, while the latter only
+former contains code derived from the library, while the latter only
works together with the library.
Note that it is possible for a library to be covered by the ordinary
@@ -104,7 +104,7 @@ General Public License rather than by this special one.
TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION
0. This License Agreement applies to any software library which
-tqcontains a notice placed by the copyright holder or other authorized
+contains a notice placed by the copyright holder or other authorized
party saying it may be distributed under the terms of this Library
General Public License (also called "this License"). Each licensee is
addressed as "you".
@@ -123,7 +123,7 @@ included without limitation in the term "modification".)
"Source code" for a work means the preferred form of the work for
making modifications to it. For a library, complete source code means
-all the source code for all modules it tqcontains, plus any associated
+all the source code for all modules it contains, plus any associated
interface definition files, plus the scripts used to control compilation
and installation of the library.
@@ -225,7 +225,7 @@ source code from the same place satisfies the requirement to
distribute the source code, even though third parties are not
compelled to copy the source along with the object code.
- 5. A program that tqcontains no derivative of any portion of the
+ 5. A program that contains no derivative of any portion of the
Library, but is designed to work with the Library by being compiled or
linked with it, is called a "work that uses the Library". Such a
work, in isolation, is not a derivative work of the Library, and
@@ -233,7 +233,7 @@ therefore falls outside the scope of this License.
However, linking a "work that uses the Library" with the Library
creates an executable that is a derivative of the Library (because it
-tqcontains portions of the Library), rather than a "work that uses the
+contains portions of the Library), rather than a "work that uses the
library". The executable is therefore covered by this License.
Section 6 states terms for distribution of such executables.
@@ -245,7 +245,7 @@ linked without the Library, or if the work is itself a library. The
threshold for this to be true is not precisely defined by law.
If such an object file uses only numerical parameters, data
-structure tqlayouts and accessors, and small macros and small inline
+structure layouts and accessors, and small macros and small inline
functions (ten lines or less in length), then the use of the object
file is unrestricted, regardless of whether it is legally a derivative
work. (Executables containing this object code plus portions of the
diff --git a/kate/ChangeLog b/kate/ChangeLog
index d3ca5da32..68dc0da01 100644
--- a/kate/ChangeLog
+++ b/kate/ChangeLog
@@ -1,5 +1,5 @@
2004-04-22 Christoph Cullmann <cullmann@kde.org>
- * kate switched over to katemdi, even smaller tqreplacement for kmdi2 :)
+ * kate switched over to katemdi, even smaller replacement for kmdi2 :)
2004-10-06 Christoph Cullmann <cullmann@kde.org>
* kate switched over to kmdi2, a slim version of old kmdi
@@ -133,7 +133,7 @@
* now the pluginconfig pages work ;)
2001-04-24 Joseph Wenninger <jowenn@kde.org>
- * now <keywords> and <types> is tqreplaced by <list name="XXXX">
+ * now <keywords> and <types> is replaced by <list name="XXXX">
2001-04-20 Christoph Cullmann <cullmann@kde.org>
* new configdialog
@@ -268,7 +268,7 @@
* Filter - select text, hit <Ctrl+Backslash>, and enter an OS command.
we pipe the selected text thru that command, such as "sort", and then
- tqreplace the selection with the result. Impress your friends.
+ replace the selection with the result. Impress your friends.
2001-02-21 Joseph Wenninger <jowenn@kde.org>
* Makefile.am's : correction for linking
diff --git a/kate/README b/kate/README
index f1a42b24b..67eb04be6 100644
--- a/kate/README
+++ b/kate/README
@@ -2,7 +2,7 @@
Kate is a fast texteditor for the KDE destop with an Emacs-style document interface.
I hope it works well and improves workspeed on many little textfiles. ;-)
Our new buffer managment will allow it to open 50MB files ++ in less than 5 seconds
-(at least on my 400Mhz P2 ;) It is thought as a more powerful tqreplacement for the old
+(at least on my 400Mhz P2 ;) It is thought as a more powerful replacement for the old
KWrite app, which will still keep alive for the existing userbase and because it is
just a lot smaller and therefor faster on launch than kate.
For Kate Plugins, Kate provides the Kate Interfaces, which allow deeper access
diff --git a/kate/app/kateapp.cpp b/kate/app/kateapp.cpp
index 084b6f313..70c81d465 100644
--- a/kate/app/kateapp.cpp
+++ b/kate/app/kateapp.cpp
@@ -127,7 +127,7 @@ Kate::Application *KateApp::application ()
/**
* Has always been the Kate Versioning Scheme:
- * KDE X.Y.Z tqcontains Kate X-1.Y.Z
+ * KDE X.Y.Z contains Kate X-1.Y.Z
*/
TQString KateApp::kateVersion (bool fullVersion)
{
@@ -396,4 +396,4 @@ KateMainWindow *KateApp::mainWindow (uint n)
return 0;
}
-// kate: space-indent on; indent-width 2; tqreplace-tabs on;
+// kate: space-indent on; indent-width 2; replace-tabs on;
diff --git a/kate/app/kateappIface.cpp b/kate/app/kateappIface.cpp
index eb8b58a4f..259e48b89 100644
--- a/kate/app/kateappIface.cpp
+++ b/kate/app/kateappIface.cpp
@@ -101,4 +101,4 @@ const TQString & KateAppDCOPIface::session() const
return m_app->sessionManager()->activeSession()->sessionName();
}
-// kate: space-indent on; indent-width 2; tqreplace-tabs on;
+// kate: space-indent on; indent-width 2; replace-tabs on;
diff --git a/kate/app/kateconfigdialog.cpp b/kate/app/kateconfigdialog.cpp
index 370abe97e..47a7de19c 100644
--- a/kate/app/kateconfigdialog.cpp
+++ b/kate/app/kateconfigdialog.cpp
@@ -334,7 +334,7 @@ void KateConfigDialog::removePluginPage (Kate::Plugin *plugin)
{
if ( pluginPages.at(i)->plugin == plugin )
{
- TQWidget *w = pluginPages.at(i)->page->tqparentWidget();
+ TQWidget *w = pluginPages.at(i)->page->parentWidget();
delete pluginPages.at(i)->page;
delete w;
pluginPages.remove(pluginPages.at(i));
diff --git a/kate/app/kateconsole.cpp b/kate/app/kateconsole.cpp
index b599ab202..a160162db 100644
--- a/kate/app/kateconsole.cpp
+++ b/kate/app/kateconsole.cpp
@@ -57,8 +57,8 @@ void KateConsole::loadConsoleIfNeeded()
{
if (m_part) return;
- if (!tqtopLevelWidget() || !tqparentWidget()) return;
- if (!tqtopLevelWidget() || !isVisibleTo(tqtopLevelWidget())) return;
+ if (!topLevelWidget() || !parentWidget()) return;
+ if (!topLevelWidget() || !isVisibleTo(topLevelWidget())) return;
KLibFactory *factory = KLibLoader::self()->factory("libkonsolepart");
@@ -86,7 +86,7 @@ void KateConsole::slotDestroyed ()
m_part = 0;
// hide the dockwidget
- if (tqparentWidget())
+ if (parentWidget())
{
m_mw->hideToolView (m_toolView);
m_mw->centralWidget()->setFocus ();
diff --git a/kate/app/katedocmanager.cpp b/kate/app/katedocmanager.cpp
index a8a13ab98..f60c09783 100644
--- a/kate/app/katedocmanager.cpp
+++ b/kate/app/katedocmanager.cpp
@@ -86,7 +86,7 @@ KateDocManager::~KateDocManager ()
{
m_metaInfos->setGroup(*it);
TQDateTime last = m_metaInfos->readDateTimeEntry("Time", def);
- if (last.daysTo(TQDateTime::tqcurrentDateTime()) > m_daysMetaInfos)
+ if (last.daysTo(TQDateTime::currentDateTime()) > m_daysMetaInfos)
m_metaInfos->deleteGroup(*it);
}
delete def;
@@ -306,7 +306,7 @@ bool KateDocManager::closeDocument(class Kate::Document *doc,bool closeURL)
KateApp::self()->mainWindow(i)->viewManager()->closeViews(documentNumber);
}
- if ( closeURL && m_tempFiles.tqcontains( documentNumber ) )
+ if ( closeURL && m_tempFiles.contains( documentNumber ) )
{
TQFileInfo fi( m_tempFiles[ documentNumber ].first.path() );
if ( fi.lastModified() <= m_tempFiles[ documentNumber ].second /*||
@@ -583,7 +583,7 @@ void KateDocManager::saveMetaInfos(Kate::Document *doc)
m_metaInfos->setGroup(doc->url().prettyURL());
doc->writeSessionConfig(m_metaInfos);
m_metaInfos->writeEntry("MD5", (const char *)md5);
- m_metaInfos->writeEntry("Time", TQDateTime::tqcurrentDateTime());
+ m_metaInfos->writeEntry("Time", TQDateTime::currentDateTime());
m_metaInfos->sync();
}
}
@@ -608,4 +608,4 @@ bool KateDocManager::computeUrlMD5(const KURL &url, TQCString &result)
return true;
}
-// kate: space-indent on; indent-width 2; tqreplace-tabs on;
+// kate: space-indent on; indent-width 2; replace-tabs on;
diff --git a/kate/app/katedocmanager.h b/kate/app/katedocmanager.h
index 56f006ea8..b35d0a65f 100644
--- a/kate/app/katedocmanager.h
+++ b/kate/app/katedocmanager.h
@@ -154,4 +154,4 @@ class KateDocManager : public QObject
};
#endif
-// kate: space-indent on; indent-width 2; tqreplace-tabs on;
+// kate: space-indent on; indent-width 2; replace-tabs on;
diff --git a/kate/app/kateexternaltools.cpp b/kate/app/kateexternaltools.cpp
index a3482f2b5..6680e26a4 100644
--- a/kate/app/kateexternaltools.cpp
+++ b/kate/app/kateexternaltools.cpp
@@ -127,7 +127,7 @@ bool KateExternalTool::checkExec()
bool KateExternalTool::valid( const TQString &mt ) const
{
- return mimetypes.isEmpty() || mimetypes.tqcontains( mt );
+ return mimetypes.isEmpty() || mimetypes.contains( mt );
}
//END KateExternalTool
@@ -191,7 +191,7 @@ bool KateExternalToolsCommand::exec (Kate::View *view, const TQString &cmd, TQSt
// kdDebug(13001)<<"KateExternalToolsCommand::exec: Could not get view widget"<<endl;
return false;
}
- KateMDI::MainWindow *dmw=dynamic_cast<KateMDI::MainWindow*>(wv->tqtopLevelWidget());
+ KateMDI::MainWindow *dmw=dynamic_cast<KateMDI::MainWindow*>(wv->topLevelWidget());
if (!dmw) {
// kdDebug(13001)<<"KateExternalToolsCommand::exec: Could not get main window"<<endl;
return false;
@@ -330,8 +330,8 @@ void KateExternalToolsMenuAction::reload()
bool sepadded = false;
for (TQStringList::iterator itg = dtools.begin(); itg != dtools.end(); ++itg )
{
- if ( ! tools.tqcontains( *itg ) &&
- ! removed.tqcontains( *itg ) )
+ if ( ! tools.contains( *itg ) &&
+ ! removed.contains( *itg ) )
{
if ( ! sepadded )
{
@@ -394,7 +394,7 @@ void KateExternalToolsMenuAction::slotDocumentChanged()
if ( action )
{
l = action->tool->mimetypes;
- b = ( ! l.count() || l.tqcontains( mt ) );
+ b = ( ! l.count() || l.contains( mt ) );
action->setEnabled( b );
}
}
@@ -439,7 +439,7 @@ KateExternalToolServiceEditor::KateExternalToolServiceEditor( KateExternalTool *
leName = new TQLineEdit( w );
lo->addWidget( leName, 1, 2 );
l = new TQLabel( leName, i18n("&Label:"), w );
- l->tqsetAlignment( l->tqalignment()|Qt::AlignRight );
+ l->setAlignment( l->alignment()|Qt::AlignRight );
lo->addWidget( l, 1, 1 );
if ( tool ) leName->setText( tool->name );
TQWhatsThis::add( leName, i18n(
@@ -454,7 +454,7 @@ KateExternalToolServiceEditor::KateExternalToolServiceEditor( KateExternalTool *
teCommand = new TQTextEdit( w );
lo->addMultiCellWidget( teCommand, 2, 2, 2, 3 );
l = new TQLabel( teCommand, i18n("S&cript:"), w );
- l->tqsetAlignment( Qt::AlignTop|Qt::AlignRight );
+ l->setAlignment( Qt::AlignTop|Qt::AlignRight );
lo->addWidget( l, 2, 1 );
if ( tool ) teCommand->setText( tool->command );
TQWhatsThis::add( teCommand, i18n(
@@ -477,7 +477,7 @@ KateExternalToolServiceEditor::KateExternalToolServiceEditor( KateExternalTool *
leExecutable = new TQLineEdit( w );
lo->addMultiCellWidget( leExecutable, 3, 3, 2, 3 );
l = new TQLabel( leExecutable, i18n("&Executable:"), w );
- l->tqsetAlignment( l->tqalignment()|Qt::AlignRight );
+ l->setAlignment( l->alignment()|Qt::AlignRight );
lo->addWidget( l, 3, 1 );
if ( tool ) leExecutable->setText( tool->tryexec );
TQWhatsThis::add( leExecutable, i18n(
@@ -488,7 +488,7 @@ KateExternalToolServiceEditor::KateExternalToolServiceEditor( KateExternalTool *
leMimetypes = new TQLineEdit( w );
lo->addWidget( leMimetypes, 4, 2 );
l = new TQLabel( leMimetypes, i18n("&Mime types:"), w );
- l->tqsetAlignment( l->tqalignment()|Qt::AlignRight );
+ l->setAlignment( l->alignment()|Qt::AlignRight );
lo->addWidget( l, 4, 1 );
if ( tool ) leMimetypes->setText( tool->mimetypes.join("; ") );
TQWhatsThis::add( leMimetypes, i18n(
@@ -506,7 +506,7 @@ KateExternalToolServiceEditor::KateExternalToolServiceEditor( KateExternalTool *
cmbSave = new TQComboBox(w);
lo->addMultiCellWidget( cmbSave, 5, 5, 2, 3 );
l = new TQLabel( cmbSave, i18n("&Save:"), w );
- l->tqsetAlignment( l->tqalignment()|Qt::AlignRight );
+ l->setAlignment( l->alignment()|Qt::AlignRight );
lo->addWidget( l, 5, 1 );
TQStringList sl;
sl << i18n("None") << i18n("Current Document") << i18n("All Documents");
@@ -521,7 +521,7 @@ KateExternalToolServiceEditor::KateExternalToolServiceEditor( KateExternalTool *
leCmdLine = new TQLineEdit( w );
lo->addMultiCellWidget( leCmdLine, 6, 6, 2, 3 );
l = new TQLabel( leCmdLine, i18n("&Command line name:"), w );
- l->tqsetAlignment( l->tqalignment()|Qt::AlignRight );
+ l->setAlignment( l->alignment()|Qt::AlignRight );
lo->addWidget( l, 6, 1 );
if ( tool ) leCmdLine->setText( tool->cmdname );
TQWhatsThis::add( leCmdLine, i18n(
@@ -745,7 +745,7 @@ void KateExternalToolsConfigWidget::slotNew()
// This is sticky, it does not change again, so that shortcuts sticks
// TODO check for dups
- t->acname = "externaltool_" + TQString(t->name).tqreplace( TQRegExp("\\W+"), "" );
+ t->acname = "externaltool_" + TQString(t->name).replace( TQRegExp("\\W+"), "" );
new ToolItem ( lbTools, t->icon.isEmpty() ? blankIcon() : SmallIcon( t->icon ), t );
@@ -870,4 +870,4 @@ void KateExternalToolsConfigWidget::slotMoveDown()
m_changed = true;
}
//END KateExternalToolsConfigWidget
-// kate: space-indent on; indent-width 2; tqreplace-tabs on;
+// kate: space-indent on; indent-width 2; replace-tabs on;
diff --git a/kate/app/kateexternaltools.h b/kate/app/kateexternaltools.h
index 71cc5eaf0..507e1cfca 100644
--- a/kate/app/kateexternaltools.h
+++ b/kate/app/kateexternaltools.h
@@ -76,7 +76,7 @@ class KateExternalToolsMenuAction : public KActionMenu
};
/**
- * This Action tqcontains a KateExternalTool
+ * This Action contains a KateExternalTool
*/
class KateExternalToolAction : public KAction, public KWordMacroExpander
{
diff --git a/kate/app/katefilelist.h b/kate/app/katefilelist.h
index 837761780..e90281558 100644
--- a/kate/app/katefilelist.h
+++ b/kate/app/katefilelist.h
@@ -188,4 +188,4 @@ class KFLConfigPage : public Kate::ConfigPage {
#endif
-// kate: space-indent on; indent-width 2; tqreplace-tabs on;
+// kate: space-indent on; indent-width 2; replace-tabs on;
diff --git a/kate/app/katefileselector.cpp b/kate/app/katefileselector.cpp
index 789b6f735..5ab42a289 100644
--- a/kate/app/katefileselector.cpp
+++ b/kate/app/katefileselector.cpp
@@ -96,7 +96,7 @@ void KateFileSelectorToolBarParent::resizeEvent ( TQResizeEvent * )
{
if (m_tb)
{
- setMinimumHeight(m_tb->tqsizeHint().height());
+ setMinimumHeight(m_tb->sizeHint().height());
m_tb->resize(width(),height());
}
}
@@ -113,17 +113,17 @@ KateFileSelector::KateFileSelector( KateMainWindow *mainWindow,
{
mActionCollection = new KActionCollection( this );
- QtMsgHandler oldHandler = tqInstallMsgHandler( silenceQToolBar );
+ QtMsgHandler oldHandler = qInstallMsgHandler( silenceQToolBar );
KateFileSelectorToolBarParent *tbp=new KateFileSelectorToolBarParent(this);
toolbar = new KateFileSelectorToolBar(tbp);
tbp->setToolBar(toolbar);
toolbar->setMovingEnabled(false);
toolbar->setFlat(true);
- tqInstallMsgHandler( oldHandler );
+ qInstallMsgHandler( oldHandler );
cmbPath = new KURLComboBox( KURLComboBox::Directories, true, this, "path combo" );
- cmbPath->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Fixed ));
+ cmbPath->setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Fixed ));
KURLCompletion* cmpl = new KURLCompletion(KURLCompletion::DirCompletion);
cmbPath->setCompletionObject( cmpl );
cmbPath->setAutoDeleteCompletionObject( true );
@@ -157,7 +157,7 @@ KateFileSelector::KateFileSelector( KateMainWindow *mainWindow,
btnFilter->setIconSet( SmallIconSet("filter" ) );
btnFilter->setToggleButton( true );
filter = new KHistoryCombo( true, filterBox, "filter");
- filter->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Fixed ));
+ filter->setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Fixed ));
filterBox->setStretchFactor(filter, 2);
connect( btnFilter, TQT_SIGNAL( clicked() ), this, TQT_SLOT( btnFilterClick() ) );
@@ -354,7 +354,7 @@ void KateFileSelector::setDir( KURL u )
newurl.setPath(pathstr);
if ( !kateFileSelectorIsReadable ( newurl ) )
- newurl.cd(TQString::tqfromLatin1(".."));
+ newurl.cd(TQString::fromLatin1(".."));
if ( !kateFileSelectorIsReadable (newurl) )
newurl.setPath( TQDir::homeDirPath() );
@@ -692,13 +692,13 @@ void KFSConfigPage::init()
KAction *ac;
TQListBox *lb;
for ( TQStringList::Iterator it=allActions.begin(); it != allActions.end(); ++it ) {
- lb = l.tqcontains( *it ) ? acSel->selectedListBox() : acSel->availableListBox();
+ lb = l.contains( *it ) ? acSel->selectedListBox() : acSel->availableListBox();
if ( *it == "bookmarks" || *it == "sync_dir" )
ac = fileSelector->actionCollection()->action( (*it).latin1() );
else
ac = fileSelector->dirOperator()->actionCollection()->action( (*it).latin1() );
if ( ac )
- new ActionLBItem( lb, SmallIcon( ac->icon() ), ac->text().tqreplace( re, "" ), *it );
+ new ActionLBItem( lb, SmallIcon( ac->icon() ), ac->text().replace( re, "" ), *it );
}
// sync
@@ -719,4 +719,4 @@ void KFSConfigPage::slotMyChanged()
slotChanged();
}
//END KFSConfigPage
-// kate: space-indent on; indent-width 2; tqreplace-tabs on;
+// kate: space-indent on; indent-width 2; replace-tabs on;
diff --git a/kate/app/katefileselector.h b/kate/app/katefileselector.h
index 4a52a6ea1..442d3101e 100644
--- a/kate/app/katefileselector.h
+++ b/kate/app/katefileselector.h
@@ -169,4 +169,4 @@ class KFSConfigPage : public Kate::ConfigPage {
#endif //__KATE_FILESELECTOR_H__
-// kate: space-indent on; indent-width 2; tqreplace-tabs on;
+// kate: space-indent on; indent-width 2; replace-tabs on;
diff --git a/kate/app/kategrepdialog.cpp b/kate/app/kategrepdialog.cpp
index 99d0b7501..409bfd0a1 100644
--- a/kate/app/kategrepdialog.cpp
+++ b/kate/app/kategrepdialog.cpp
@@ -85,22 +85,22 @@ GrepTool::GrepTool(TQWidget *parent, const char *name)
<< "*";
}
- TQGridLayout *tqlayout = new TQGridLayout(this, 6, 3, 4, 4);
- tqlayout->setColStretch(0, 10);
- tqlayout->addColSpacing(1, 10);
- tqlayout->setColStretch(1, 0);
- tqlayout->setColStretch(2, 1);
- tqlayout->setRowStretch(1, 0);
- tqlayout->setRowStretch(2, 10);
- tqlayout->setRowStretch(4, 0);
+ TQGridLayout *layout = new TQGridLayout(this, 6, 3, 4, 4);
+ layout->setColStretch(0, 10);
+ layout->addColSpacing(1, 10);
+ layout->setColStretch(1, 0);
+ layout->setColStretch(2, 1);
+ layout->setRowStretch(1, 0);
+ layout->setRowStretch(2, 10);
+ layout->setRowStretch(4, 0);
TQGridLayout *loInput = new TQGridLayout(4, 2, 4);
- tqlayout->addLayout(loInput, 0, 0);
+ layout->addLayout(loInput, 0, 0);
loInput->setColStretch(0, 0);
loInput->setColStretch(1, 20);
TQLabel *lPattern = new TQLabel(i18n("Pattern:"), this);
- lPattern->setFixedSize(lPattern->tqsizeHint());
+ lPattern->setFixedSize(lPattern->sizeHint());
loInput->addWidget(lPattern, 0, 0, AlignRight | AlignVCenter);
TQBoxLayout *loPattern = new TQHBoxLayout( 4 );
@@ -112,22 +112,22 @@ GrepTool::GrepTool(TQWidget *parent, const char *name)
cmbPattern->setInsertionPolicy(TQComboBox::NoInsertion);
lPattern->setBuddy(cmbPattern);
cmbPattern->setFocus();
- cmbPattern->setMinimumSize(cmbPattern->tqsizeHint());
+ cmbPattern->setMinimumSize(cmbPattern->sizeHint());
loPattern->addWidget( cmbPattern );
cbCasesensitive = new TQCheckBox(i18n("Case sensitive"), this);
- cbCasesensitive->setMinimumWidth(cbCasesensitive->tqsizeHint().width());
+ cbCasesensitive->setMinimumWidth(cbCasesensitive->sizeHint().width());
cbCasesensitive->setChecked(config->readBoolEntry("CaseSensitive", true));
loPattern->addWidget(cbCasesensitive);
cbRegex = new TQCheckBox( i18n("Regular expression"), this );
- cbRegex->setMinimumWidth( cbRegex->tqsizeHint().width() );
+ cbRegex->setMinimumWidth( cbRegex->sizeHint().width() );
cbRegex->setChecked( config->readBoolEntry( "Regex", true ) );
loPattern->addWidget( cbRegex );
loPattern->setStretchFactor( cmbPattern, 100 );
TQLabel *lTemplate = new TQLabel(i18n("Template:"), this);
- lTemplate->setFixedSize(lTemplate->tqsizeHint());
+ lTemplate->setFixedSize(lTemplate->sizeHint());
loInput->addWidget(lTemplate, 1, 0, AlignRight | AlignVCenter);
TQBoxLayout *loTemplate = new TQHBoxLayout(4);
@@ -136,7 +136,7 @@ GrepTool::GrepTool(TQWidget *parent, const char *name)
leTemplate = new KLineEdit(this);
lTemplate->setBuddy(leTemplate);
leTemplate->setText(strTemplate[0]);
- leTemplate->setMinimumSize(leTemplate->tqsizeHint());
+ leTemplate->setMinimumSize(leTemplate->sizeHint());
loTemplate->addWidget(leTemplate);
KComboBox *cmbTemplate = new KComboBox(false, this);
@@ -146,19 +146,19 @@ GrepTool::GrepTool(TQWidget *parent, const char *name)
loTemplate->addWidget(cmbTemplate);
TQLabel *lFiles = new TQLabel(i18n("Files:"), this);
- lFiles->setFixedSize(lFiles->tqsizeHint());
+ lFiles->setFixedSize(lFiles->sizeHint());
loInput->addWidget(lFiles, 2, 0, AlignRight | AlignVCenter);
cmbFiles = new KComboBox(true, this);
lFiles->setBuddy(cmbFiles->focusProxy());
- cmbFiles->setMinimumSize(cmbFiles->tqsizeHint());
+ cmbFiles->setMinimumSize(cmbFiles->sizeHint());
cmbFiles->setInsertionPolicy(TQComboBox::NoInsertion);
cmbFiles->setDuplicatesEnabled(false);
cmbFiles->insertStringList(lastSearchFiles);
loInput->addWidget(cmbFiles, 2, 1);
TQLabel *lDir = new TQLabel(i18n("Folder:"), this);
- lDir->setFixedSize(lDir->tqsizeHint());
+ lDir->setFixedSize(lDir->sizeHint());
loInput->addWidget(lDir, 3, 0, AlignRight | AlignVCenter);
TQBoxLayout *loDir = new TQHBoxLayout(3);
@@ -176,24 +176,24 @@ GrepTool::GrepTool(TQWidget *parent, const char *name)
lDir->setBuddy(cmbDir);
cbRecursive = new TQCheckBox(i18n("Recursive"), this);
- cbRecursive->setMinimumWidth(cbRecursive->tqsizeHint().width());
+ cbRecursive->setMinimumWidth(cbRecursive->sizeHint().width());
cbRecursive->setChecked(config->readBoolEntry("Recursive", true));
loDir->addWidget(cbRecursive);
KButtonBox *actionbox = new KButtonBox(this, Qt::Vertical);
- tqlayout->addWidget(actionbox, 0, 2);
+ layout->addWidget(actionbox, 0, 2);
actionbox->addStretch();
btnSearch = static_cast<KPushButton*>(actionbox->addButton(KGuiItem(i18n("Find"),"find")));
btnSearch->setDefault(true);
btnClear = static_cast<KPushButton*>(actionbox->addButton( KStdGuiItem::clear() ));
actionbox->addStretch();
- actionbox->tqlayout();
+ actionbox->layout();
lbResult = new TQListBox(this);
TQFontMetrics rb_fm(lbResult->fontMetrics());
- tqlayout->addMultiCellWidget(lbResult, 2, 2, 0, 2);
+ layout->addMultiCellWidget(lbResult, 2, 2, 0, 2);
- tqlayout->activate();
+ layout->activate();
KAcceleratorManager::manage( this );
@@ -225,11 +225,11 @@ GrepTool::GrepTool(TQWidget *parent, const char *name)
"You may give several patterns separated by commas."));
TQWhatsThis::add(lTemplate,
i18n("You can choose a template for the pattern from the combo box\n"
- "and edit it here. The string %s in the template is tqreplaced\n"
+ "and edit it here. The string %s in the template is replaced\n"
"by the pattern input field, resulting in the regular expression\n"
"to search for."));
TQWhatsThis::add(lDir,
- i18n("Enter the folder which tqcontains the files in which you want to search."));
+ i18n("Enter the folder which contains the files in which you want to search."));
TQWhatsThis::add(cbRecursive,
i18n("Check this box to search in all subfolders."));
TQWhatsThis::add(cbCasesensitive,
@@ -329,7 +329,7 @@ void GrepTool::slotSearch()
return;
}
- if ( ! leTemplate->text().tqcontains("%s") )
+ if ( ! leTemplate->text().contains("%s") )
{
leTemplate->setFocus();
return;
@@ -347,9 +347,9 @@ void GrepTool::slotSearch()
TQString s = cmbPattern->currentText();
if ( ! cbRegex->isChecked() )
- s.tqreplace( TQRegExp( "([^\\w'()<>])" ), "\\\\1" );
+ s.replace( TQRegExp( "([^\\w'()<>])" ), "\\\\1" );
TQString pattern = leTemplate->text();
- pattern.tqreplace( "%s", s );
+ pattern.replace( "%s", s );
childproc = new KProcess();
childproc->setWorkingDirectory( m_workingDir );
@@ -476,7 +476,7 @@ void GrepTool::childExited()
if ( ! errbuf.isEmpty() )
{
- KMessageBox::information( tqparentWidget(), i18n("<strong>Error:</strong><p>") + errbuf, i18n("Grep Tool Error") );
+ KMessageBox::information( parentWidget(), i18n("<strong>Error:</strong><p>") + errbuf, i18n("Grep Tool Error") );
errbuf.truncate(0);
}
else
diff --git a/kate/app/katemailfilesdialog.cpp b/kate/app/katemailfilesdialog.cpp
index 52bf1f243..79a1e19c6 100644
--- a/kate/app/katemailfilesdialog.cpp
+++ b/kate/app/katemailfilesdialog.cpp
@@ -78,7 +78,7 @@ KateMailDialog::KateMailDialog( TQWidget *parent, KateMainWindow *mainwin )
}
list->hide();
connect( this, TQT_SIGNAL(user1Clicked()), this, TQT_SLOT(slotShowButton()) );
- mw->setMinimumSize( lInfo->tqsizeHint() );
+ mw->setMinimumSize( lInfo->sizeHint() );
}
TQPtrList<Kate::Document> KateMailDialog::selectedDocs()
@@ -105,8 +105,8 @@ void KateMailDialog::slotShowButton()
lInfo->setText( i18n("Press <strong>Mail...</strong> to send selected documents") );
}
- mw->setMinimumSize( TQSize( lInfo->tqsizeHint().width(), mw->tqsizeHint().height()) );
- setMinimumSize( calculateSize( mw->tqminimumSize().width(), mw->tqsizeHint().height() ) );
+ mw->setMinimumSize( TQSize( lInfo->sizeHint().width(), mw->sizeHint().height()) );
+ setMinimumSize( calculateSize( mw->minimumSize().width(), mw->sizeHint().height() ) );
resize( width(), minimumHeight() );
}
#include "katemailfilesdialog.moc"
diff --git a/kate/app/katemain.cpp b/kate/app/katemain.cpp
index 9ba62782a..371161de0 100644
--- a/kate/app/katemain.cpp
+++ b/kate/app/katemain.cpp
@@ -253,4 +253,4 @@ extern "C" KDE_EXPORT int kdemain( int argc, char **argv )
return app.exec();
}
-// kate: space-indent on; indent-width 2; tqreplace-tabs on; mixed-indent off;
+// kate: space-indent on; indent-width 2; replace-tabs on; mixed-indent off;
diff --git a/kate/app/katemainwindow.cpp b/kate/app/katemainwindow.cpp
index 331194159..dea2b0fae 100644
--- a/kate/app/katemainwindow.cpp
+++ b/kate/app/katemainwindow.cpp
@@ -101,7 +101,7 @@ KateMainWindow::KateMainWindow (KConfig *sconfig, const TQString &sgroup)
// here we go, set some usable default sizes
if (!initialGeometrySet())
{
- int scnum = TQApplication::desktop()->screenNumber(tqparentWidget());
+ int scnum = TQApplication::desktop()->screenNumber(parentWidget());
TQRect desk = TQApplication::desktop()->screenGeometry(scnum);
TQSize size;
@@ -110,8 +110,8 @@ KateMainWindow::KateMainWindow (KConfig *sconfig, const TQString &sgroup)
if (sconfig)
{
sconfig->setGroup (sgroup);
- size.setWidth (sconfig->readNumEntry( TQString::tqfromLatin1("Width %1").arg(desk.width()), 0 ));
- size.setHeight (sconfig->readNumEntry( TQString::tqfromLatin1("Height %1").arg(desk.height()), 0 ));
+ size.setWidth (sconfig->readNumEntry( TQString::fromLatin1("Width %1").arg(desk.width()), 0 ));
+ size.setHeight (sconfig->readNumEntry( TQString::fromLatin1("Height %1").arg(desk.height()), 0 ));
}
// if thats fails, try to reuse size
@@ -131,8 +131,8 @@ KateMainWindow::KateMainWindow (KConfig *sconfig, const TQString &sgroup)
{
// first try global app config
KateApp::self()->config()->setGroup ("MainWindow");
- size.setWidth (KateApp::self()->config()->readNumEntry( TQString::tqfromLatin1("Width %1").arg(desk.width()), 0 ));
- size.setHeight (KateApp::self()->config()->readNumEntry( TQString::tqfromLatin1("Height %1").arg(desk.height()), 0 ));
+ size.setWidth (KateApp::self()->config()->readNumEntry( TQString::fromLatin1("Width %1").arg(desk.width()), 0 ));
+ size.setHeight (KateApp::self()->config()->readNumEntry( TQString::fromLatin1("Height %1").arg(desk.height()), 0 ));
if (size.isEmpty())
size = TQSize (kMin (700, desk.width()), kMin(480, desk.height()));
@@ -851,4 +851,4 @@ void KateMainWindow::saveGlobalProperties( KConfig* sessionConfig )
sessionConfig->writeEntry ("Last Session", KateApp::self()->sessionManager()->activeSession()->sessionFileRelative());
}
-// kate: space-indent on; indent-width 2; tqreplace-tabs on;
+// kate: space-indent on; indent-width 2; replace-tabs on;
diff --git a/kate/app/katemainwindow.h b/kate/app/katemainwindow.h
index e0859bcbd..77db9999c 100644
--- a/kate/app/katemainwindow.h
+++ b/kate/app/katemainwindow.h
@@ -213,4 +213,4 @@ class KateMainWindow : public KateMDI::MainWindow, virtual public KParts::PartBa
#endif
-// kate: space-indent on; indent-width 2; tqreplace-tabs on;
+// kate: space-indent on; indent-width 2; replace-tabs on;
diff --git a/kate/app/katemdi.cpp b/kate/app/katemdi.cpp
index 64aef77bc..9d73e762c 100644
--- a/kate/app/katemdi.cpp
+++ b/kate/app/katemdi.cpp
@@ -128,7 +128,7 @@ GUIClient::GUIClient ( MainWindow *mw )
if ( domDocument().documentElement().isNull() )
{
- TQString completeDescription = TQString::tqfromLatin1( guiDescription )
+ TQString completeDescription = TQString::fromLatin1( guiDescription )
.arg( actionListName );
setXML( completeDescription, false /*merge*/ );
@@ -339,7 +339,7 @@ ToolView *Sidebar::addWidget (const TQPixmap &icon, const TQString &text, ToolVi
bool Sidebar::removeWidget (ToolView *widget)
{
- if (!m_widgetToId.tqcontains(widget))
+ if (!m_widgetToId.contains(widget))
return false;
removeTab(m_widgetToId[widget]);
@@ -369,7 +369,7 @@ bool Sidebar::removeWidget (ToolView *widget)
bool Sidebar::showWidget (ToolView *widget)
{
- if (!m_widgetToId.tqcontains(widget))
+ if (!m_widgetToId.contains(widget))
return false;
// hide other non-persistent views
@@ -394,7 +394,7 @@ bool Sidebar::showWidget (ToolView *widget)
bool Sidebar::hideWidget (ToolView *widget)
{
- if (!m_widgetToId.tqcontains(widget))
+ if (!m_widgetToId.contains(widget))
return false;
bool anyVis = false;
@@ -579,7 +579,7 @@ void Sidebar::restoreSession (KConfig *config)
}
// then: remove this items from the button bar
- // do this backwards, to minimize the retqlayout efforts
+ // do this backwards, to minimize the relayout efforts
for (int i=m_toolviews.size()-1; i >= (int)firstWrong; --i)
{
removeTab (m_widgetToId[m_toolviews[i]]);
@@ -659,8 +659,8 @@ void Sidebar::saveSession (KConfig *config)
//BEGIN MAIN WINDOW
-MainWindow::MainWindow (TQWidget* tqparentWidget, const char* name)
- : KParts::MainWindow( tqparentWidget, name)
+MainWindow::MainWindow (TQWidget* parentWidget, const char* name)
+ : KParts::MainWindow( parentWidget, name)
, m_sidebarsVisible(true)
, m_restoreConfig (0)
, m_guiClient (new GUIClient (this))
diff --git a/kate/app/katemdi.h b/kate/app/katemdi.h
index 915589d77..1b13c30a8 100644
--- a/kate/app/katemdi.h
+++ b/kate/app/katemdi.h
@@ -258,7 +258,7 @@ class MainWindow : public KParts::MainWindow
/**
* Constructor
*/
- MainWindow (TQWidget* tqparentWidget = 0, const char* name = 0);
+ MainWindow (TQWidget* parentWidget = 0, const char* name = 0);
/**
* Destructor
diff --git a/kate/app/katemwmodonhddialog.cpp b/kate/app/katemwmodonhddialog.cpp
index 263d06c7e..5199a6925 100644
--- a/kate/app/katemwmodonhddialog.cpp
+++ b/kate/app/katemwmodonhddialog.cpp
@@ -91,7 +91,7 @@ KateMwModOnHdDialog::KateMwModOnHdDialog( DocVector docs, TQWidget *parent, cons
// document list
lvDocuments = new KListView( w );
lvDocuments->addColumn( i18n("Filename") );
- lvDocuments->addColumn( i18n("tqStatus on Disk") );
+ lvDocuments->addColumn( i18n("Status on Disk") );
lvDocuments->setSelectionMode( TQListView::Single );
TQStringList l;
@@ -278,4 +278,4 @@ void KateMwModOnHdDialog::slotPDone( KProcess *p )
m_tmpfile = 0;
}
-// kate: space-indent on; indent-width 2; tqreplace-tabs on;
+// kate: space-indent on; indent-width 2; replace-tabs on;
diff --git a/kate/app/katemwmodonhddialog.h b/kate/app/katemwmodonhddialog.h
index 121761f38..7a5d8f7ca 100644
--- a/kate/app/katemwmodonhddialog.h
+++ b/kate/app/katemwmodonhddialog.h
@@ -58,4 +58,4 @@ class KateMwModOnHdDialog : public KDialogBase
};
#endif // _KATE_MW_MODONHD_DIALOG_H_
-// kate: space-indent on; indent-width 2; tqreplace-tabs on;
+// kate: space-indent on; indent-width 2; replace-tabs on;
diff --git a/kate/app/katesession.cpp b/kate/app/katesession.cpp
index 70c844804..fd0e059f9 100644
--- a/kate/app/katesession.cpp
+++ b/kate/app/katesession.cpp
@@ -917,4 +917,4 @@ void KateSessionsAction::openSession (int i)
KateSessionManager::self()->activateSession(slist[(uint)i]);
}
-// kate: space-indent on; indent-width 2; tqreplace-tabs on; mixed-indent off;
+// kate: space-indent on; indent-width 2; replace-tabs on; mixed-indent off;
diff --git a/kate/app/katetabwidget.cpp b/kate/app/katetabwidget.cpp
index cd9df55d1..4b278e327 100644
--- a/kate/app/katetabwidget.cpp
+++ b/kate/app/katetabwidget.cpp
@@ -70,7 +70,7 @@ void KateTabWidget::insertTab ( TQWidget * child, const TQString & label, int in
KTabWidget::insertTab(child,label,index);
showPage(child);
maybeShow();
- tabBar()->tqrepaint();
+ tabBar()->repaint();
}
void KateTabWidget::insertTab ( TQWidget * child, const TQIconSet & iconset, const TQString & label, int index )
@@ -78,7 +78,7 @@ void KateTabWidget::insertTab ( TQWidget * child, const TQIconSet & iconset, con
KTabWidget::insertTab(child,iconset,label,index);
showPage(child);
maybeShow();
- tabBar()->tqrepaint();
+ tabBar()->repaint();
}
void KateTabWidget::insertTab ( TQWidget * child, TQTab * tab, int index)
@@ -86,7 +86,7 @@ void KateTabWidget::insertTab ( TQWidget * child, TQTab * tab, int index)
KTabWidget::insertTab(child,tab,index);
showPage(child);
maybeShow();
- tabBar()->tqrepaint();
+ tabBar()->repaint();
}
void KateTabWidget::removePage ( TQWidget * w )
diff --git a/kate/app/kateviewmanager.cpp b/kate/app/kateviewmanager.cpp
index 08f080fec..c62e6e082 100644
--- a/kate/app/kateviewmanager.cpp
+++ b/kate/app/kateviewmanager.cpp
@@ -511,4 +511,4 @@ KateMainWindow *KateViewManager::mainWindow() {
return m_mainWindow;
}
-// kate: space-indent on; indent-width 2; tqreplace-tabs on;
+// kate: space-indent on; indent-width 2; replace-tabs on;
diff --git a/kate/app/kateviewspace.cpp b/kate/app/kateviewspace.cpp
index de7090215..43a73a2b6 100644
--- a/kate/app/kateviewspace.cpp
+++ b/kate/app/kateviewspace.cpp
@@ -67,9 +67,9 @@ protected:
void paintEvent( TQPaintEvent *e )
{
TQPainter p( this );
- p.setPen( tqcolorGroup().shadow() );
+ p.setPen( colorGroup().shadow() );
p.drawLine( e->rect().left(), 0, e->rect().right(), 0 );
- p.setPen( ((KateViewSpace*)tqparentWidget())->isActiveSpace() ? tqcolorGroup().light() : tqcolorGroup().midlight() );
+ p.setPen( ((KateViewSpace*)parentWidget())->isActiveSpace() ? colorGroup().light() : colorGroup().midlight() );
p.drawLine( e->rect().left(), 1, e->rect().right(), 1 );
}
};
@@ -226,9 +226,9 @@ bool KateViewSpace::event( TQEvent *e )
return TQVBox::event( e );
}
-void KateViewSpace::slottqStatusChanged (Kate::View *view, int r, int c, int ovr, bool block, int mod, const TQString &msg)
+void KateViewSpace::slotStatusChanged (Kate::View *view, int r, int c, int ovr, bool block, int mod, const TQString &msg)
{
- if ((TQWidgetStack *)view->tqparentWidget() != stack)
+ if ((TQWidgetStack *)view->parentWidget() != stack)
return;
mStatusBar->setStatus( r, c, ovr, block, mod, msg );
}
@@ -309,29 +309,29 @@ KateVSStatusBar::KateVSStatusBar ( KateViewSpace *parent, const char *name )
{
m_lineColLabel = new TQLabel( this );
addWidget( m_lineColLabel, 0, false );
- m_lineColLabel->tqsetAlignment( Qt::AlignCenter );
+ m_lineColLabel->setAlignment( Qt::AlignCenter );
m_lineColLabel->installEventFilter( this );
m_modifiedLabel = new TQLabel( TQString(" "), this );
addWidget( m_modifiedLabel, 0, false );
- m_modifiedLabel->tqsetAlignment( Qt::AlignCenter );
+ m_modifiedLabel->setAlignment( Qt::AlignCenter );
m_modifiedLabel->installEventFilter( this );
m_insertModeLabel = new TQLabel( i18n(" INS "), this );
addWidget( m_insertModeLabel, 0, false );
- m_insertModeLabel->tqsetAlignment( Qt::AlignCenter );
+ m_insertModeLabel->setAlignment( Qt::AlignCenter );
m_insertModeLabel->installEventFilter( this );
m_selectModeLabel = new TQLabel( i18n(" NORM "), this );
addWidget( m_selectModeLabel, 0, false );
- m_selectModeLabel->tqsetAlignment( Qt::AlignCenter );
+ m_selectModeLabel->setAlignment( Qt::AlignCenter );
m_selectModeLabel->installEventFilter( this );
m_fileNameLabel=new KSqueezedTextLabel( this );
addWidget( m_fileNameLabel, 1, true );
m_fileNameLabel->setMinimumSize( 0, 0 );
- m_fileNameLabel->tqsetSizePolicy(TQSizePolicy( TQSizePolicy::Ignored, TQSizePolicy::Fixed ));
- m_fileNameLabel->tqsetAlignment( /*Qt::AlignRight*/Qt::AlignLeft );
+ m_fileNameLabel->setSizePolicy(TQSizePolicy( TQSizePolicy::Ignored, TQSizePolicy::Fixed ));
+ m_fileNameLabel->setAlignment( /*Qt::AlignRight*/Qt::AlignLeft );
m_fileNameLabel->installEventFilter( this );
installEventFilter( this );
@@ -396,7 +396,7 @@ void KateVSStatusBar::modifiedChanged()
void KateVSStatusBar::showMenu()
{
- KMainWindow* mainWindow = static_cast<KMainWindow*>( tqtopLevelWidget() );
+ KMainWindow* mainWindow = static_cast<KMainWindow*>( topLevelWidget() );
TQPopupMenu* menu = static_cast<TQPopupMenu*>( mainWindow->factory()->container("viewspace_popup", mainWindow ) );
if (menu)
@@ -419,4 +419,4 @@ bool KateVSStatusBar::eventFilter(TQObject*,TQEvent *e)
return false;
}
//END KateVSStatusBar
-// kate: space-indent on; indent-width 2; tqreplace-tabs on;
+// kate: space-indent on; indent-width 2; replace-tabs on;
diff --git a/kate/app/kateviewspace.h b/kate/app/kateviewspace.h
index 9f1106aab..b6a5a185e 100644
--- a/kate/app/kateviewspace.h
+++ b/kate/app/kateviewspace.h
@@ -110,7 +110,7 @@ class KateViewSpace : public QVBox
TQString m_group;
private slots:
- void slottqStatusChanged (Kate::View *view, int r, int c, int ovr, bool block, int mod, const TQString &msg);
+ void slotStatusChanged (Kate::View *view, int r, int c, int ovr, bool block, int mod, const TQString &msg);
public slots:
void polish();
@@ -118,4 +118,4 @@ class KateViewSpace : public QVBox
};
#endif
-// kate: space-indent on; indent-width 2; tqreplace-tabs on;
+// kate: space-indent on; indent-width 2; replace-tabs on;
diff --git a/kate/app/kateviewspacecontainer.cpp b/kate/app/kateviewspacecontainer.cpp
index a441e3adb..1e05e8b5a 100644
--- a/kate/app/kateviewspacecontainer.cpp
+++ b/kate/app/kateviewspacecontainer.cpp
@@ -69,7 +69,7 @@ KateViewSpaceContainer::KateViewSpaceContainer (TQWidget *parent, KateViewManage
m_viewSpaceList.setAutoDelete(true);
KateViewSpace* vs = new KateViewSpace( this, this );
- connect(this, TQT_SIGNAL(statusChanged(Kate::View *, int, int, int, bool, int, const TQString&)), vs, TQT_SLOT(slottqStatusChanged(Kate::View *, int, int, int, bool, int, const TQString&)));
+ connect(this, TQT_SIGNAL(statusChanged(Kate::View *, int, int, int, bool, int, const TQString&)), vs, TQT_SLOT(slotStatusChanged(Kate::View *, int, int, int, bool, int, const TQString&)));
vs->setActive( true );
m_viewSpaceList.append(vs);
connect( this, TQT_SIGNAL(viewChanged()), this, TQT_SLOT(slotViewChanged()) );
@@ -124,7 +124,7 @@ bool KateViewSpaceContainer::createView ( Kate::Document *doc )
connect(view->getDoc(),TQT_SIGNAL(nameChanged(Kate::Document *)),this,TQT_SLOT(statusMsg()));
connect(view,TQT_SIGNAL(cursorPositionChanged()),this,TQT_SLOT(statusMsg()));
- connect(view,TQT_SIGNAL(newtqStatus()),this,TQT_SLOT(statusMsg()));
+ connect(view,TQT_SIGNAL(newStatus()),this,TQT_SLOT(statusMsg()));
connect(view->getDoc(), TQT_SIGNAL(undoChanged()), this, TQT_SLOT(statusMsg()));
connect(view,TQT_SIGNAL(dropEventPass(TQDropEvent *)), mainWindow(),TQT_SLOT(slotDropEvent(TQDropEvent *)));
connect(view,TQT_SIGNAL(gotFocus(Kate::View *)),this,TQT_SLOT(activateSpace(Kate::View *)));
@@ -141,7 +141,7 @@ bool KateViewSpaceContainer::deleteView (Kate::View *view, bool delViewSpace)
{
if (!view) return true;
- KateViewSpace *viewspace = (KateViewSpace *)view->tqparentWidget()->tqparentWidget();
+ KateViewSpace *viewspace = (KateViewSpace *)view->parentWidget()->parentWidget();
viewspace->removeView (view);
@@ -241,7 +241,7 @@ void KateViewSpaceContainer::activateSpace (Kate::View* v)
{
if (!v) return;
- KateViewSpace* vs = (KateViewSpace*)v->tqparentWidget()->tqparentWidget();
+ KateViewSpace* vs = (KateViewSpace*)v->parentWidget()->parentWidget();
if (!vs->isActiveSpace()) {
setActiveSpace (vs);
@@ -446,23 +446,23 @@ void KateViewSpaceContainer::splitViewSpace( KateViewSpace* vs,
if (!activeView()) return;
if (!vs) vs = activeViewSpace();
- bool isFirstTime = vs->tqparentWidget() == this;
+ bool isFirstTime = vs->parentWidget() == this;
TQValueList<int> psizes;
if ( ! isFirstTime )
- if ( TQSplitter *ps = static_cast<TQSplitter*>(vs->tqparentWidget()->qt_cast("TQSplitter")) )
+ if ( TQSplitter *ps = static_cast<TQSplitter*>(vs->parentWidget()->qt_cast("TQSplitter")) )
psizes = ps->sizes();
Qt::Orientation o = isHoriz ? Qt::Vertical : Qt::Horizontal;
- KateMDI::Splitter* s = new KateMDI::Splitter(o, vs->tqparentWidget());
+ KateMDI::Splitter* s = new KateMDI::Splitter(o, vs->parentWidget());
s->setOpaqueResize( KGlobalSettings::opaqueResize() );
if (! isFirstTime) {
// anders: make sure the split' viewspace is always
// correctly positioned.
// If viewSpace is the first child, the new splitter must be moveToFirst'd
- if ( !((KateMDI::Splitter*)vs->tqparentWidget())->isLastChild( vs ) )
- ((KateMDI::Splitter*)s->tqparentWidget())->moveToFirst( s );
+ if ( !((KateMDI::Splitter*)vs->parentWidget())->isLastChild( vs ) )
+ ((KateMDI::Splitter*)s->parentWidget())->moveToFirst( s );
}
vs->reparent( s, 0, TQPoint(), true );
KateViewSpace* vsNew = new KateViewSpace( this, s );
@@ -471,17 +471,17 @@ void KateViewSpaceContainer::splitViewSpace( KateViewSpace* vs,
s->moveToFirst( vsNew );
if (!isFirstTime)
- if (TQSplitter *ps = static_cast<TQSplitter*>(s->tqparentWidget()->qt_cast("TQSplitter")) )
+ if (TQSplitter *ps = static_cast<TQSplitter*>(s->parentWidget()->qt_cast("TQSplitter")) )
ps->setSizes( psizes );
s->show();
TQValueList<int> sizes;
- int space = 50;//isHoriz ? s->tqparentWidget()->height()/2 : s->tqparentWidget()->width()/2;
+ int space = 50;//isHoriz ? s->parentWidget()->height()/2 : s->parentWidget()->width()/2;
sizes << space << space;
s->setSizes( sizes );
- connect(this, TQT_SIGNAL(statusChanged(Kate::View *, int, int, int, bool, int, const TQString &)), vsNew, TQT_SLOT(slottqStatusChanged(Kate::View *, int, int,int, bool, int, const TQString &)));
+ connect(this, TQT_SIGNAL(statusChanged(Kate::View *, int, int, int, bool, int, const TQString &)), vsNew, TQT_SLOT(slotStatusChanged(Kate::View *, int, int,int, bool, int, const TQString &)));
m_viewSpaceList.append( vsNew );
activeViewSpace()->setActive( false );
vsNew->setActive( true, true );
@@ -503,7 +503,7 @@ void KateViewSpaceContainer::removeViewSpace (KateViewSpace *viewspace)
// abort if this is the last viewspace
if (m_viewSpaceList.count() < 2) return;
- KateMDI::Splitter* p = (KateMDI::Splitter*)viewspace->tqparentWidget();
+ KateMDI::Splitter* p = (KateMDI::Splitter*)viewspace->parentWidget();
// find out if it is the first child for repositioning
// see below
@@ -512,9 +512,9 @@ void KateViewSpaceContainer::removeViewSpace (KateViewSpace *viewspace)
// save some size information
KateMDI::Splitter* pp=0L;
TQValueList<int> ppsizes;
- if (m_viewSpaceList.count() > 2 && p->tqparentWidget() != this)
+ if (m_viewSpaceList.count() > 2 && p->parentWidget() != this)
{
- pp = (KateMDI::Splitter*)p->tqparentWidget();
+ pp = (KateMDI::Splitter*)p->parentWidget();
ppsizes = pp->sizes();
pIsFirst = !pp->isLastChild( p ); // simple logic, right-
}
@@ -554,10 +554,10 @@ void KateViewSpaceContainer::removeViewSpace (KateViewSpace *viewspace)
{
TQWidget* other = ((TQWidget *)(( TQPtrList<TQObject>*)p->children())->first());
- other->reparent( p->tqparentWidget(), 0, TQPoint(), true );
+ other->reparent( p->parentWidget(), 0, TQPoint(), true );
// We also need to find the right viewspace to become active
if (pIsFirst)
- ((KateMDI::Splitter*)p->tqparentWidget())->moveToFirst( other );
+ ((KateMDI::Splitter*)p->parentWidget())->moveToFirst( other );
if ( other->isA("KateViewSpace") ) {
setActiveSpace( (KateViewSpace*)other );
}
@@ -726,7 +726,7 @@ void KateViewSpaceContainer::restoreSplitter( KConfig* config, const TQString &g
{
KateViewSpace* vs = new KateViewSpace( this, s );
- connect(this, TQT_SIGNAL(statusChanged(Kate::View *, int, int, int, bool, int, const TQString &)), vs, TQT_SLOT(slottqStatusChanged(Kate::View *, int, int, int, bool, int, const TQString &)));
+ connect(this, TQT_SIGNAL(statusChanged(Kate::View *, int, int, int, bool, int, const TQString &)), vs, TQT_SLOT(slotStatusChanged(Kate::View *, int, int, int, bool, int, const TQString &)));
if (m_viewSpaceList.isEmpty())
vs->setActive (true);
@@ -755,4 +755,4 @@ KateMainWindow *KateViewSpaceContainer::mainWindow() {
return m_viewManager->mainWindow();
}
-// kate: space-indent on; indent-width 2; tqreplace-tabs on;
+// kate: space-indent on; indent-width 2; replace-tabs on;
diff --git a/kate/app/kwritemain.cpp b/kate/app/kwritemain.cpp
index 2ac1e5d9e..efb71b767 100644
--- a/kate/app/kwritemain.cpp
+++ b/kate/app/kwritemain.cpp
@@ -96,8 +96,8 @@ KWrite::KWrite (KTextEditor::Document *doc)
setAcceptDrops(true);
- connect(m_view,TQT_SIGNAL(newtqStatus()),this,TQT_SLOT(newCaption()));
- connect(m_view,TQT_SIGNAL(viewtqStatusMsg(const TQString &)),this,TQT_SLOT(newtqStatus(const TQString &)));
+ connect(m_view,TQT_SIGNAL(newStatus()),this,TQT_SLOT(newCaption()));
+ connect(m_view,TQT_SIGNAL(viewStatusMsg(const TQString &)),this,TQT_SLOT(newStatus(const TQString &)));
connect(m_view->document(),TQT_SIGNAL(fileNameChanged()),this,TQT_SLOT(newCaption()));
connect(m_view->document(),TQT_SIGNAL(fileNameChanged()),this,TQT_SLOT(slotFileNameChanged()));
connect(m_view,TQT_SIGNAL(dropEventPass(TQDropEvent *)),this,TQT_SLOT(slotDropEvent(TQDropEvent *)));
@@ -112,7 +112,7 @@ KWrite::KWrite (KTextEditor::Document *doc)
// init with more usefull size, stolen from konq :)
if (!initialGeometrySet())
- resize( TQSize(700, 480).expandedTo(tqminimumSizeHint()));
+ resize( TQSize(700, 480).expandedTo(minimumSizeHint()));
// call it as last thing, must be sure everything is already set up ;)
setAutoSaveSettings ();
@@ -163,7 +163,7 @@ void KWrite::setupActions()
// setup Settings menu
setStandardToolBarMenuEnabled(true);
- m_paShowStatusBar = KStdAction::showtqStatusbar(this, TQT_SLOT(toggleStatusBar()), actionCollection(), "settings_show_statusbar");
+ m_paShowStatusBar = KStdAction::showStatusbar(this, TQT_SLOT(toggleStatusBar()), actionCollection(), "settings_show_statusbar");
m_paShowStatusBar->setWhatsThis(i18n("Use this command to show or hide the view's statusbar"));
m_paShowPath = new KToggleAction(i18n("Sho&w Path"), 0, this, TQT_SLOT(newCaption()),
@@ -320,7 +320,7 @@ void KWrite::printDlg()
KTextEditor::printInterface(m_view->document())->printDialog ();
}
-void KWrite::newtqStatus(const TQString &msg)
+void KWrite::newStatus(const TQString &msg)
{
newCaption();
@@ -709,4 +709,4 @@ void KWriteEditorChooser::slotOk() {
m_chooser->writeAppSetting();
KDialogBase::slotOk();
}
-// kate: space-indent on; indent-width 2; tqreplace-tabs on; mixed-indent off;
+// kate: space-indent on; indent-width 2; replace-tabs on; mixed-indent off;
diff --git a/kate/app/kwritemain.h b/kate/app/kwritemain.h
index 91c4240ff..6a3565a6c 100644
--- a/kate/app/kwritemain.h
+++ b/kate/app/kwritemain.h
@@ -76,7 +76,7 @@ class KWrite : public KParts::MainWindow
void printNow();
void printDlg();
- void newtqStatus(const TQString &msg);
+ void newStatus(const TQString &msg);
void newCaption();
void slotDropEvent(TQDropEvent *);
@@ -135,4 +135,4 @@ class KWriteEditorChooser: public KDialogBase
};
#endif
-// kate: space-indent on; indent-width 2; tqreplace-tabs on; mixed-indent off;
+// kate: space-indent on; indent-width 2; replace-tabs on; mixed-indent off;
diff --git a/kate/data/tips b/kate/data/tips
index 5d74a1202..aaee34424 100644
--- a/kate/data/tips
+++ b/kate/data/tips
@@ -83,9 +83,9 @@ in the active frame.</p>
</tip>
<tip category="Kate|part">
<html>
-<p>You can do cool sed-like regular expression tqreplacements using <em>Command Line</em>.</p>
+<p>You can do cool sed-like regular expression replacements using <em>Command Line</em>.</p>
<p>For example, press <strong>F7</strong> and enter <code>s /oldtext/newtext/g</code>
-to tqreplace &quot;oldtext&quot; with &quot;newtext&quot; throughout the current
+to replace &quot;oldtext&quot; with &quot;newtext&quot; throughout the current
line.</p>
</html>
</tip>
diff --git a/kate/interfaces/mainwindow.cpp b/kate/interfaces/mainwindow.cpp
index 26dbe913d..4596cacb5 100644
--- a/kate/interfaces/mainwindow.cpp
+++ b/kate/interfaces/mainwindow.cpp
@@ -79,4 +79,4 @@ ToolViewManager *MainWindow::toolViewManager () const
}
-// kate: space-indent on; indent-width 2; tqreplace-tabs on;
+// kate: space-indent on; indent-width 2; replace-tabs on;
diff --git a/kate/interfaces/mainwindow.h b/kate/interfaces/mainwindow.h
index b0874458a..5c8449b62 100644
--- a/kate/interfaces/mainwindow.h
+++ b/kate/interfaces/mainwindow.h
@@ -62,4 +62,4 @@ class KDE_EXPORT MainWindow : public QObject
#endif
-// kate: space-indent on; indent-width 2; tqreplace-tabs on;
+// kate: space-indent on; indent-width 2; replace-tabs on;
diff --git a/kate/utils/dockviewbase.cpp b/kate/utils/dockviewbase.cpp
index 6048f9b70..76e5844ed 100644
--- a/kate/utils/dockviewbase.cpp
+++ b/kate/utils/dockviewbase.cpp
@@ -87,7 +87,7 @@ void Kate::DockViewBase::init( const TQString &prefix, const TQString &title )
{
setSpacing( 4 );
d->header = new TQWidget( this );
- d->header->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Fixed, true ) );
+ d->header->setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Fixed, true ) );
TQHBoxLayout *lo = new TQHBoxLayout( d->header );
lo->setSpacing( 6 );
lo->insertSpacing( 0, 6 );
diff --git a/kate/app/katefilelist.cpp b/kate/app/katefilelist.cpp
index 343f66a9a..47c8aa75b 100644
--- a/kate/app/katefilelist.cpp
+++ b/kate/app/katefilelist.cpp
@@ -69,7 +69,7 @@ class ToolTip : public QToolTip
KateFileListItem *item = ((KateFileListItem*)i);
if ( ! item ) return;
- tip( m_listView->tqitemRect( i ), m_listView->tooltip( item, 0 ) );
+ tip( m_listView->itemRect( i ), m_listView->tooltip( item, 0 ) );
}
@@ -273,11 +273,11 @@ void KateFileList::slotModChanged (Kate::Document *doc)
for ( uint i=0; i < m_editHistory.count(); i++ )
{
m_editHistory.at( i )->setEditHistPos( i+1 );
- tqrepaintItem( m_editHistory.at( i ) );
+ repaintItem( m_editHistory.at( i ) );
}
}
else
- tqrepaintItem( item );
+ repaintItem( item );
}
void KateFileList::slotModifiedOnDisc (Kate::Document *doc, bool, unsigned char)
@@ -296,7 +296,7 @@ void KateFileList::slotNameChanged (Kate::Document *doc)
if ( ((KateFileListItem*)item)->document() == doc )
{
item->setText( 0, doc->docName() );
- tqrepaintItem( item );
+ repaintItem( item );
break;
}
item = item->nextSibling();
@@ -334,7 +334,7 @@ void KateFileList::slotViewChanged ()
// int p = 0;
// if ( m_viewHistory.count() )
// {
// int p = m_viewHistory.findRef( item ); // only tqrepaint items that needs it
// }
m_viewHistory.removeRef( item );
@@ -343,7 +343,7 @@ void KateFileList::slotViewChanged ()
for ( uint i=0; i < m_viewHistory.count(); i++ )
{
m_viewHistory.at( i )->setViewHistPos( i+1 );
- tqrepaintItem( m_viewHistory.at( i ) );
+ repaintItem( m_viewHistory.at( i ) );
}
}
@@ -475,7 +475,7 @@ void KateFileListItem::paintCell( TQPainter *painter, const TQColorGroup & cg, i
{
TQColorGroup cgNew = cg;
- // tqreplace the base color with a different shading if necessary...
+ // replace the base color with a different shading if necessary...
if ( fl->shadingEnabled() && m_viewhistpos > 1 )
{
TQColor b( cg.base() );
@@ -616,7 +616,7 @@ void KFLConfigPage::apply()
m_filelist->m_editShade = kcbEditShade->color();
m_filelist->m_enableBgShading = cbEnableShading->isChecked();
m_filelist->setSortType( cmbSort->currentItem() );
// tqrepaint the affected items
m_filelist->triggerUpdate();
}
@@ -649,4 +649,4 @@ void KFLConfigPage::slotMyChanged()
//END KFLConfigPage
-// kate: space-indent on; indent-width 2; tqreplace-tabs on;
+// kate: space-indent on; indent-width 2; replace-tabs on;
@@ -334,7 +334,7 @@ void KateFileList::slotViewChanged ()
// if ( m_viewHistory.count() )
// {
-// int p = m_viewHistory.findRef( item ); // only tqrepaint items that needs it
+// int p = m_viewHistory.findRef( item ); // only repaint items that needs it
// }
m_viewHistory.removeRef( item );
@@ -616,7 +616,7 @@ void KFLConfigPage::apply()
m_filelist->m_enableBgShading = cbEnableShading->isChecked();
m_filelist->setSortType( cmbSort->currentItem() );
- // tqrepaint the affected items
+ // repaint the affected items
m_filelist->triggerUpdate();
}